@@ -7,8 +7,8 @@
 #'
 #' @param formula modeling formula
 #' @param data data.frame containing features and dependent variable
-#' @param lambda1 L1 regularization term
-#' @param lambda2 L2 regularization term
+#' @param lambda regularization term
+#' @param alpha mixing parameter, alpha=0 corresponds to L2 regularization and alpha=1 to L1.
 #' @param a learning rate parameter
 #' @param b learning rate parameter controlling decay, defaults to 1.
 #' @param num_epochs number of times we should traverse over the traiing set, defaults to 1.
@@ -27,16 +27,16 @@
 #' dat <- as.data.frame(p)
 #' 
 #' mdl <- ftrlprox(classes ~ x.1 + x.2 + I(x.1^2) + I(x.2^2), dat,
-#'                 a=1, b=1, lambda1=5.0, lambda2=0.0)
+#'                 a = 0.3, lambda = 5.0, alpha = 1.0)
 #' print(mdl)
 ##------------------------------------------------------------------------------
-ftrlprox.formula <- function(formula, data, lambda1, lambda2, a, b=1, num_epochs=1, save_loss=F, ...) {
+ftrlprox.formula <- function(formula, data, lambda, alpha, a, b=1, num_epochs=1, save_loss=F, ...) {
 
   X <- model.matrix(formula, data)
   y <- data[[all.vars(formula[[2]])]]
 
   ftrlprox(X,y,a=a,b=b,
-           lambda1=lambda1, lambda2=lambda2,
+           lambda=lambda, alpha=alpha,
            num_epochs=num_epochs, save_loss=save_loss)
 }
 
