@@ -6,7 +6,8 @@
 #' 
 #' @param object The model object to use for prediction.
 #' @param newdata the new dataset to predict the outcome of.
-#' @param type the type of response.
+#' @param type the type of response. Can be 'class' for class perdictions or
+#' 'response' for probabilities. Default option is 'response'.
 #' @param ... additional args
 #' @return an array containing the predictions
 #' 
@@ -14,7 +15,9 @@
 #' @useDynLib FTRLProximal
 #' @export
 ##------------------------------------------------------------------------------
-predict.ftrlprox <- function(object, newdata=NULL, type="response", ...) {
+predict.ftrlprox <- function(object, newdata=NULL, type=c("response", "class"), ...) {
+  type=match.arg(type)
+
   out <- .C("lognet_predict",
             X=as.double(newdata),
             theta=as.double(object$theta),
@@ -22,6 +25,8 @@ predict.ftrlprox <- function(object, newdata=NULL, type="response", ...) {
             m=as.integer(nrow(newdata)),
             n=as.integer(ncol(newdata)))
 
-  return(out$y)
+  switch(type,
+         response = out$y,
+         class = factor(ifelse(out$y<0.5, 1, 2), labels=object$levels))
 }
 
