@@ -14,11 +14,8 @@ theta <- numeric(3)
 names(theta) <- c("(Intercept)", "A", "B")
 
 # Set up enpty object
-mdl <- initialize.ftrlprox(theta, c("G", "B"), a=1, b=1, lambda1=0, lambda2=0)
+mdl <- initialize.ftrlprox(theta, c("G", "B"), a=0.3, b=1, lambda=0, alpha=0)
 
-# Update model using the rest of the data this should generate the same result
-# as training once using all data.
-mdl <- update(mdl, X, dat$y)
 
 test_that("Class is ftrlprox", {
           expect_is(mdl, "ftrlprox")
@@ -26,11 +23,23 @@ test_that("Class is ftrlprox", {
 
 test_that("Parameter values", {
           coefs <- mdl$theta
-          names(coefs) <- NULL
+          expected <- c('(Intercept)' = 0.0, 'A' = 0.0, 'B' = 0.0)
 
-          expect_equal(coefs[1], -0.38188318762577)
-          expect_equal(coefs[2], -2.23889313859288)
-          expect_equal(coefs[3], -1.69555552563667)
+          expect_equal(coefs, expected, tolerance=1e-8)
+})
+
+
+test_that("Parameter values after update", {
+          # Update model using the rest of the data this should generate the same result
+          # as training once using all data.
+          mdl <- update(mdl, X, dat$y)
+
+          coefs <- mdl$theta
+          expected <- c('(Intercept)' = -0.110366358105649,
+                        'A' = -1.303382372935719,
+                        'B' = -1.169874403463117)
+
+          expect_equal(coefs, expected, tolerance=1e-8)
 })
 
 test_that("Parameter names", {
